summaryrefslogtreecommitdiff
path: root/edgemesh
diff options
context:
space:
mode:
authorbetter0332 <whl@netbank.cn>2020-05-31 14:40:28 +0800
committerGitHub <noreply@github.com>2020-05-31 14:40:28 +0800
commit54c6b0c7824edc92c08892b43cbe65eec67ae9b1 (patch)
tree7f3debec70c4bf0922b1be894991f7d76095736e /edgemesh
parentMerge pull request #1697 from ls889/logss (diff)
downloadkubeedge-54c6b0c7824edc92c08892b43cbe65eec67ae9b1.tar.gz
fix spell check
Diffstat (limited to 'edgemesh')
-rw-r--r--edgemesh/tools/initContainer/script/edgemesh-iptables.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/edgemesh/tools/initContainer/script/edgemesh-iptables.sh b/edgemesh/tools/initContainer/script/edgemesh-iptables.sh
index 9db02766e..1447ef7fb 100644
--- a/edgemesh/tools/initContainer/script/edgemesh-iptables.sh
+++ b/edgemesh/tools/initContainer/script/edgemesh-iptables.sh
@@ -4,10 +4,10 @@ function usage() {
echo 'this is the edgemesh-iptables usage'
echo "${0} -p PROXY_PORT [-i HIJACK_IP] [-t HIJACK_PORT] [-b EXCLUDE_IP] [-c EXCLUDE_PORT] [-h]"
echo ''
- echo ' -p: Specify the edgemesh port to which all TCP traffic from the Pod will be redirectd to. (default 10001)'
- echo ' -i: Comma separated list of outbound IP for which tarffic is to be redirectd to edgemesh. The'
+ echo ' -p: Specify the edgemesh port to which all TCP traffic from the Pod will be redirected to. (default 10001)'
+ echo ' -i: Comma separated list of outbound IP for which traffic is to be redirected to edgemesh. The'
echo ' wildcard character "*" can be used to configure redirection for all IPs. (default "*")'
- echo ' -t: Comma separated list of outbound Port for which tarffic is to be redirectd to edgemesh. The'
+ echo ' -t: Comma separated list of outbound Port for which traffic is to be redirected to edgemesh. The'
echo ' wildcard character "*" can be used to configure redirection for all Ports. (default "*")'
echo ' -b: Comma separated list of outbound IP range in CIDR to be excluded from redirection to edgemesh.'
echo ' The Empty character "" can be used to configure redirection for all IPs. (default "")'
@@ -106,7 +106,7 @@ function bridgeNetMode() {
done
fi
# Redirect app callback to itself via Servie IP (default not redirectd)
get_local_IP=$(ip addr |grep inet|grep -v inet6|awk '{print $2}'|tr -d "addr:")
for LOCAL_IP in $get_local_IP; do
@@ -106,7 +106,7 @@ function bridgeNetMode() {
done
fi
- # Redirect app callback to itself via Servie IP (default not redirectd)
+ # Redirect app callback to itself via Service IP (default not redirected)
get_local_IP=$(ip addr |grep inet|grep -v inet6|awk '{print $2}'|tr -d "addr:")
for LOCAL_IP in $get_local_IP; do